@@ -25,6 +25,7 @@ G_BEGIN_DECLS
 #define g_marshal_value_peek_boxed(v)    g_value_get_boxed (v)
 #define g_marshal_value_peek_pointer(v)  g_value_get_pointer (v)
 #define g_marshal_value_peek_object(v)   g_value_get_object (v)
+#define g_marshal_value_peek_variant(v)  g_value_get_variant (v)
 #else /* !G_ENABLE_DEBUG */
 /* WARNING: This code accesses GValues directly, which is UNSUPPORTED API.
  *          Do not access GValues directly in your code. Instead, use the
@@ -48,19 +49,11 @@ G_BEGIN_DECLS
 #define g_marshal_value_peek_boxed(v)    (v)->data[0].v_pointer
 #define g_marshal_value_peek_pointer(v)  (v)->data[0].v_pointer
 #define g_marshal_value_peek_object(v)   (v)->data[0].v_pointer
+#define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:VOID (clock-marshallers.list:1) */
-#define _clock_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
-
-/* VOID:OBJECT (clock-marshallers.list:2) */
-#define _clock_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
-
-/* VOID:POINTER (clock-marshallers.list:3) */
-#define _clock_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
-
-/* POINTER:VOID (clock-marshallers.list:4) */
+/* POINTER:VOID (clock-marshallers.list:1) */
 G_GNUC_INTERNAL void _clock_marshal_POINTER__VOID (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -103,7 +96,7 @@ _clock_marshal_POINTER__VOID (GClosure     *closure,
   g_value_set_pointer (return_value, v_return);
 }
 
-/* VOID:OBJECT,STRING (clock-marshallers.list:5) */
+/* VOID:OBJECT,STRING (clock-marshallers.list:2) */
 G_GNUC_INTERNAL void _clock_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -146,27 +139,27 @@ _clock_marshal_VOID__OBJECT_STRING (GClosure     *closure,
             data2);
 }
 
-/* STRING:VOID (clock-marshallers.list:6) */
-G_GNUC_INTERNAL void _clock_marshal_STRING__VOID (GClosure     *closure,
-                                                  GValue       *return_value,
-                                                  guint         n_param_values,
-                                                  const GValue *param_values,
-                                                  gpointer      invocation_hint,
-                                                  gpointer      marshal_data);
+/* INT:VOID (clock-marshallers.list:3) */
+G_GNUC_INTERNAL void _clock_marshal_INT__VOID (GClosure     *closure,
+                                               GValue       *return_value,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint,
+                                               gpointer      marshal_data);
 void
-_clock_marshal_STRING__VOID (GClosure     *closure,
-                             GValue       *return_value G_GNUC_UNUSED,
-                             guint         n_param_values,
-                             const GValue *param_values,
-                             gpointer      invocation_hint G_GNUC_UNUSED,
-                             gpointer      marshal_data)
+_clock_marshal_INT__VOID (GClosure     *closure,
+                          GValue       *return_value G_GNUC_UNUSED,
+                          guint         n_param_values,
+                          const GValue *param_values,
+                          gpointer      invocation_hint G_GNUC_UNUSED,
+                          gpointer      marshal_data)
 {
-  typedef gchar* (*GMarshalFunc_STRING__VOID) (gpointer     data1,
-                                               gpointer     data2);
-  register GMarshalFunc_STRING__VOID callback;
+  typedef gint (*GMarshalFunc_INT__VOID) (gpointer     data1,
+                                          gpointer     data2);
+  register GMarshalFunc_INT__VOID callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
-  gchar* v_return;
+  gint v_return;
 
   g_return_if_fail (return_value != NULL);
   g_return_if_fail (n_param_values == 1);
@@ -181,12 +174,12 @@ _clock_marshal_STRING__VOID (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_STRING__VOID) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_INT__VOID) (marshal_data ? marshal_data : cc->callback);
 
   v_return = callback (data1,
                        data2);
 
-  g_value_take_string (return_value, v_return);
+  g_value_set_int (return_value, v_return);
 }
 
 G_END_DECLS
