@@ -31,6 +31,7 @@
 #include <time.h>
 
 #include <cairo.h>
+#include <cairo-xlib.h>
 
 #include <glib/gi18n.h>
 #include <glib-object.h>
@@ -72,16 +73,15 @@ typedef struct {
 
 	GtkWidget         *frame;
 	GtkWidget         *drawing_area;
-	GdkRectangle       prev_allocation;
-	GdkPixmap         *pixmap;
+	GtkRequisition     requisition;
+	GtkAllocation      prev_allocation;
+	cairo_surface_t   *surface;
 	guint              timeout;
 	int                current_frame;
 	gboolean           in_applet;
 
 	GdkPixbuf         *pixbuf;
 
-	GtkWidget         *about_dialog;
-
 	GtkWidget         *preferences_dialog;
 	GtkWidget         *name_entry;
 	GtkWidget         *command_label;
@@ -112,7 +112,7 @@ typedef struct {
 
 
 static gboolean load_fish_image          (FishApplet *fish);
-static void     update_pixmap            (FishApplet *fish);
+static void     update_surface           (FishApplet *fish);
 static void     something_fishy_going_on (FishApplet *fish,
 					  const char *message);
 static void     display_fortune_dialog   (FishApplet *fish);
@@ -408,9 +408,8 @@ chooser_preview_update (GtkFileChooser *file_chooser,
 }
 
 static void 
-display_preferences_dialog (BonoboUIComponent *uic,
-			    FishApplet        *fish,
-			    const char        *verbname)
+display_preferences_dialog (GtkAction  *action,
+			    FishApplet *fish)
 {
 	GtkBuilder    *builder;
 	GError        *error;
@@ -569,81 +568,6 @@ display_preferences_dialog (BonoboUIComponent *uic,
 	g_object_unref (builder);
 }
 
-static void
-display_help_dialog (BonoboUIComponent *uic,
-		     FishApplet        *fish,
-		     const char        *verbname)
-{
-	show_help (fish, NULL);
-}
-
-static void
-display_about_dialog (BonoboUIComponent *uic,
-		      FishApplet        *fish,
-		      const char        *verbname)
-{
-	const char *author_format = _("%s the Fish");
-	const char *about_format = _("%s has no use what-so-ever. "
-				     "It only takes up disk space and "
-				     "compilation time, and if loaded it also "
-				     "takes up precious panel space and "
-				     "memory. Anybody found using it should be "
-				     "promptly sent for a psychiatric "
-				     "evaluation.");
-	const char  *documenters [] = {
-		"Telsa Gwynne <hobbit@aloss.ukuu.org.uk>",
-		"Sun GNOME Documentation Team <gdocteam@sun.com>",
-          	NULL
-	};
-
-	char        *authors [3];
-	char        *descr;
-
-	if (fish->about_dialog) {
-		gtk_window_set_screen (GTK_WINDOW (fish->about_dialog),
-				       gtk_widget_get_screen (GTK_WIDGET (fish)));
-		gtk_window_present (GTK_WINDOW (fish->about_dialog));
-		return;
-	}
-
-	authors [0] = g_strdup_printf (author_format, fish->name);
-	authors [1] = _("(with minor help from George)");
-	authors [2] = NULL;
-
-	descr = g_strdup_printf (about_format, fish->name);
-		
-	fish->about_dialog = gtk_about_dialog_new ();
-	g_object_set (fish->about_dialog,
-		      "program-name", _("Fish"),
-		      "version", "3.4.7.4ac19",
-		      "copyright", "Copyright \xc2\xa9 1998-2002 Free Software Foundation, Inc.",
-		      "comments", descr,
-		      "authors", (const char **) authors,
-		      "documenters", documenters,
-		      "translator-credits", _("translator-credits"),
-		      "logo-icon-name", FISH_ICON,
-		      NULL);
-
-	g_free (descr);
-	g_free (authors [0]);
-
-	gtk_window_set_icon_name (GTK_WINDOW (fish->about_dialog), FISH_ICON);
-	gtk_window_set_wmclass (
-		GTK_WINDOW (fish->about_dialog), "fish", "Fish");
-	gtk_window_set_screen (GTK_WINDOW (fish->about_dialog),
-			       gtk_widget_get_screen (GTK_WIDGET (fish)));
-
-	g_signal_connect (fish->about_dialog, "destroy",
-			  G_CALLBACK (gtk_widget_destroyed),
-			  &fish->about_dialog);
-
-	g_signal_connect (fish->about_dialog, "response",
-			  G_CALLBACK (gtk_widget_destroy),
-			  NULL);
-
-	gtk_widget_show (fish->about_dialog);
-}
-
 static void
 set_ally_name_desc (GtkWidget  *widget,
 		    FishApplet *fish)
@@ -874,6 +798,15 @@ fish_read_output (GIOChannel   *source,
 	return (status != G_IO_STATUS_EOF);
 }
 
+/*
+ * Set the DISPLAY variable, to be use by g_spawn_async.
+ */
+static void
+set_environment (gpointer display)
+{
+	g_setenv ("DISPLAY", display, TRUE);
+}
+
 static void 
 display_fortune_dialog (FishApplet *fish)
 {
@@ -883,6 +816,8 @@ display_fortune_dialog (FishApplet *fish)
 	const char  *charset;
 	int          argc;
 	char       **argv;
+	GdkScreen   *screen;
+	char        *display;
 
 	/* if there is still a pipe, close it */
 	if (fish->source_id)
@@ -896,6 +831,7 @@ display_fortune_dialog (FishApplet *fish)
 
 	if (!fish->fortune_dialog) {
 		GtkWidget *scrolled;
+		GtkWidget *vbox;
 		GdkScreen *screen;
 		int        screen_width;
 		int        screen_height;
@@ -909,8 +845,6 @@ display_fortune_dialog (FishApplet *fish)
 
 		gtk_window_set_icon_name (GTK_WINDOW (fish->fortune_dialog),
 					  FISH_ICON);
-		gtk_dialog_set_has_separator (
-			GTK_DIALOG (fish->fortune_dialog), FALSE);
 
 		gtk_dialog_set_default_response (
 			GTK_DIALOG (fish->fortune_dialog), GTK_RESPONSE_CLOSE);
@@ -959,15 +893,16 @@ display_fortune_dialog (FishApplet *fish)
 		gtk_misc_set_alignment (GTK_MISC (fish->fortune_cmd_label),
 					0, 0.5);
 
-		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fish->fortune_dialog)->vbox), 
+		vbox = gtk_dialog_get_content_area (GTK_DIALOG (fish->fortune_dialog));
+		gtk_box_pack_start (GTK_BOX (vbox),
 				    fish->fortune_label,
 				    FALSE, FALSE, 6);
 
-		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fish->fortune_dialog)->vbox), 
+		gtk_box_pack_start (GTK_BOX (vbox),
 				    scrolled,
 				    TRUE, TRUE, 6);
 
-		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fish->fortune_dialog)->vbox), 
+		gtk_box_pack_start (GTK_BOX (vbox),
 				    fish->fortune_cmd_label,
 				    FALSE, FALSE, 6);
 
@@ -1000,11 +935,22 @@ display_fortune_dialog (FishApplet *fish)
 
 	clear_fortune_text (fish);
 
-	gdk_spawn_on_screen_with_pipes (gtk_widget_get_screen (GTK_WIDGET (fish)),
-					NULL, argv, NULL,
-					G_SPAWN_SEARCH_PATH|G_SPAWN_STDERR_TO_DEV_NULL,
-					NULL, NULL, NULL, NULL, &output, NULL,
-					&error);
+	screen = gtk_widget_get_screen (GTK_WIDGET (fish));
+	display = gdk_screen_make_display_name (screen);
+
+	g_spawn_async_with_pipes (NULL, /* working directory */
+				  argv,
+				  NULL, /* envp */
+				  G_SPAWN_SEARCH_PATH|G_SPAWN_STDERR_TO_DEV_NULL,
+				  set_environment,
+				  &display,
+				  NULL, /* child pid */
+				  NULL, /* stdin */
+				  &output,
+				  NULL, /* stderr */
+				  &error);
+
+	g_free (display);
 
 	if (error) {
 		char *message;
@@ -1095,7 +1041,7 @@ image_changed_notify (GConfClient *client,
 	fish->image = g_strdup (value);
 
 	load_fish_image (fish);
-	update_pixmap (fish);
+	update_surface (fish);
 
 	if (fish->image_chooser) {
 		char *path_gconf;
@@ -1158,7 +1104,7 @@ n_frames_changed_notify (GConfClient *client,
 	if (fish->n_frames <= 0)
 		fish->n_frames = 1;
 
-	update_pixmap (fish);
+	update_surface (fish);
 
 	if (fish->frames_spin &&
 	    gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (fish->frames_spin)) != fish->n_frames)
@@ -1254,13 +1200,13 @@ check_april_fools (FishApplet *fish)
 	     tm->tm_mday != fools_day   ||
 	     tm->tm_hour >= fools_hour_end)) {
 		fish->april_fools = FALSE;
-		update_pixmap (fish);
+		update_surface (fish);
 	} else if (tm->tm_mon  == fools_month    &&
 		 tm->tm_mday == fools_day        &&
 		 tm->tm_hour >= fools_hour_start &&
 		 tm->tm_hour <= fools_hour_end) {
 		fish->april_fools = TRUE;
-		update_pixmap (fish);
+		update_surface (fish);
 	}
 }
 
@@ -1337,7 +1283,7 @@ rotate_changed_notify (GConfClient *client,
 
 	if (fish->orientation == PANEL_APPLET_ORIENT_LEFT ||
 	    fish->orientation == PANEL_APPLET_ORIENT_RIGHT)
-		update_pixmap (fish);
+		update_surface (fish);
 
 	if (fish->rotate_toggle &&
 	    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fish->rotate_toggle)) != fish->rotate)
@@ -1455,22 +1401,33 @@ load_fish_image (FishApplet *fish)
 	return TRUE;
 }
 
-static void
-update_pixmap (FishApplet *fish)
+static gboolean
+update_surface_in_idle (gpointer data)
 {
-	GtkWidget *widget = fish->drawing_area;
-	int        width  = -1;
-	int        height = -1;
-	int        pixbuf_width = -1;
-	int        pixbuf_height = -1;
-	gboolean   rotate = FALSE;
-	cairo_t   *cr;
+	update_surface (FISH_APPLET (data));
+	return FALSE;
+}
+
+static void
+update_surface (FishApplet *fish)
+{
+	GtkWidget     *widget = fish->drawing_area;
+	GtkRequisition prev_requisition;
+	GtkAllocation  allocation;
+	int            width  = -1;
+	int            height = -1;
+	int            pixbuf_width = -1;
+	int            pixbuf_height = -1;
+	gboolean       rotate = FALSE;
+	cairo_t       *cr;
 	cairo_matrix_t matrix;
 	cairo_pattern_t *pattern;
 
+	gtk_widget_get_allocation (widget, &allocation);
+
 	if (!gtk_widget_get_realized (widget) ||
-	    widget->allocation.width <= 0 ||
-	    widget->allocation.height <= 0)
+	    allocation.width <= 0 ||
+	    allocation.height <= 0)
 		return;
 
 	if (!fish->pixbuf && !load_fish_image (fish))
@@ -1484,37 +1441,53 @@ update_pixmap (FishApplet *fish)
 	pixbuf_width  = gdk_pixbuf_get_width  (fish->pixbuf);
 	pixbuf_height = gdk_pixbuf_get_height (fish->pixbuf);
 
+	prev_requisition = fish->requisition;
+
 	if (fish->orientation == PANEL_APPLET_ORIENT_UP ||
 	    fish->orientation == PANEL_APPLET_ORIENT_DOWN) {
-		height = widget->allocation.height;
+		height = allocation.height;
 		width  = pixbuf_width * ((gdouble) height / pixbuf_height);
-		widget->requisition.width = width / fish->n_frames;
+
+		fish->requisition.width = width / fish->n_frames;
+		fish->requisition.height = height;
 	} else {
 		if (!rotate) {
-			width = widget->allocation.width * fish->n_frames;
+			width = allocation.width * fish->n_frames;
 			height = pixbuf_height * ((gdouble) width / pixbuf_width);
-			widget->requisition.height = height;
+			fish->requisition.width = allocation.width;
+			fish->requisition.height = height;
 		} else {
-			width = widget->allocation.width;
+			width = allocation.width;
 			height = pixbuf_width * ((gdouble) width / pixbuf_height);
-			widget->requisition.height = height / fish->n_frames;
+			fish->requisition.width = width;
+			fish->requisition.height = height / fish->n_frames;
 		}
 	}
 
+	if (prev_requisition.width  != fish->requisition.width ||
+	    prev_requisition.height != fish->requisition.height) {
+		gtk_widget_set_size_request (widget,
+					     fish->requisition.width,
+					     fish->requisition.height);
+	}
+
 	g_assert (width != -1 && height != -1);
 
 	if (width == 0 || height == 0)
 		return;
 
-	if (fish->pixmap)
-		g_object_unref (fish->pixmap);
-	fish->pixmap = gdk_pixmap_new (widget->window, width, height, -1);
+	if (fish->surface)
+		cairo_surface_destroy (fish->surface);
+	fish->surface = gdk_window_create_similar_surface (
+			               gtk_widget_get_window (widget),
+			               CAIRO_CONTENT_COLOR_ALPHA,
+			               width, height);
 
 	gtk_widget_queue_resize (widget);
 
 	g_assert (pixbuf_width != -1 && pixbuf_height != -1);
 
-	cr = gdk_cairo_create (fish->pixmap);
+	cr = cairo_create (fish->surface);
 
 	cairo_set_source_rgb (cr, 1, 1, 1);
 	cairo_paint (cr);
@@ -1562,38 +1535,40 @@ update_pixmap (FishApplet *fish)
 }
 
 static gboolean
-fish_applet_expose_event (GtkWidget      *widget,
-			  GdkEventExpose *event,
-			  FishApplet     *fish)
+fish_applet_draw (GtkWidget  *widget,
+		  cairo_t    *cr,
+		  FishApplet *fish)
 {
+	GdkWindow *window;
 	int width, height;
 	int src_x, src_y;
 
-	g_return_val_if_fail (fish->pixmap != NULL, FALSE);
+	g_return_val_if_fail (fish->surface != NULL, FALSE);
 
 	g_assert (fish->n_frames > 0);
 
-	gdk_drawable_get_size (fish->pixmap, &width, &height);
+	window = gtk_widget_get_window (widget);
 
-	src_x = event->area.x;
-	src_y = event->area.y;
+	width = cairo_xlib_surface_get_width (fish->surface);
+	height = cairo_xlib_surface_get_height (fish->surface);
+
+	src_x = 0;
+	src_y = 0;
 
 	if (fish->rotate) {
 		if (fish->orientation == PANEL_APPLET_ORIENT_RIGHT)
-			src_y += ((height * (fish->n_frames - 1 - fish->current_frame)) / fish->n_frames);
+			src_y = ((height * (fish->n_frames - 1 - fish->current_frame)) / fish->n_frames);
 		else if (fish->orientation == PANEL_APPLET_ORIENT_LEFT)
-			src_y += ((height * fish->current_frame) / fish->n_frames);
+			src_y = ((height * fish->current_frame) / fish->n_frames);
 		else
-			src_x += ((width * fish->current_frame) / fish->n_frames);
+			src_x = ((width * fish->current_frame) / fish->n_frames);
 	} else
-		src_x += ((width * fish->current_frame) / fish->n_frames);
+		src_x = ((width * fish->current_frame) / fish->n_frames);
 
-	gdk_draw_drawable (widget->window,
-			   widget->style->fg_gc [GTK_WIDGET_STATE (widget)],
-			   fish->pixmap,
-			   src_x, src_y,
-			   event->area.x, event->area.y,
-			   event->area.width, event->area.height);
+        cairo_save (cr);
+        cairo_set_source_surface (cr, fish->surface, -src_x, -src_y);
+        cairo_paint (cr);
+        cairo_restore (cr);
 
         return FALSE;
 }
@@ -1603,28 +1578,29 @@ fish_applet_size_allocate (GtkWidget     *widget,
 			   GtkAllocation *allocation,
 			   FishApplet    *fish)
 {
-	if (widget->allocation.width  != fish->prev_allocation.width ||
-	    widget->allocation.height != fish->prev_allocation.height)
-		update_pixmap (fish);
+	if (allocation->width  == fish->prev_allocation.width &&
+	    allocation->height == fish->prev_allocation.height)
+		return;
 
 	fish->prev_allocation = *allocation;
+	g_idle_add (update_surface_in_idle, fish);
 }
 
 static void
 fish_applet_realize (GtkWidget  *widget,
 		     FishApplet *fish)
 {
-	if (!fish->pixmap)
-		update_pixmap (fish);
+	if (!fish->surface)
+		update_surface (fish);
 }
 
 static void
 fish_applet_unrealize (GtkWidget  *widget,
 		       FishApplet *fish)
 {
-	if (fish->pixmap)
-		g_object_unref (fish->pixmap);
-	fish->pixmap = NULL;
+	if (fish->surface)
+		cairo_surface_destroy (fish->surface);
+	fish->surface = NULL;
 }
 
 static void
@@ -1638,8 +1614,8 @@ fish_applet_change_orient (PanelApplet       *applet,
 
 	fish->orientation = orientation;
 
-	if (fish->pixmap)
-		update_pixmap (fish);
+	if (fish->surface)
+		update_surface (fish);
 }
 
 static void
@@ -1670,12 +1646,12 @@ handle_keypress (GtkWidget   *widget,
 		 FishApplet  *fish)
 {
 	switch (event->keyval) {
-	case GDK_space:
-	case GDK_KP_Space:
-	case GDK_Return:
-	case GDK_KP_Enter:
-	case GDK_ISO_Enter:
-	case GDK_3270_Enter:
+	case GDK_KEY_space:
+	case GDK_KEY_KP_Space:
+	case GDK_KEY_Return:
+	case GDK_KEY_KP_Enter:
+	case GDK_KEY_ISO_Enter:
+	case GDK_KEY_3270_Enter:
 		if (fish->april_fools) {
 			change_water (fish);
 			return TRUE;
@@ -1771,8 +1747,8 @@ setup_fish_widget (FishApplet *fish)
 			  G_CALLBACK (fish_applet_unrealize), fish);
 	g_signal_connect (fish->drawing_area, "size-allocate",
 			  G_CALLBACK (fish_applet_size_allocate), fish);
-	g_signal_connect (fish->drawing_area, "expose-event",
-			  G_CALLBACK (fish_applet_expose_event), fish);
+	g_signal_connect (fish->drawing_area, "draw",
+			  G_CALLBACK (fish_applet_draw), fish);
 
 	gtk_widget_add_events (widget, GDK_ENTER_NOTIFY_MASK | 
 				       GDK_LEAVE_NOTIFY_MASK |
@@ -1791,7 +1767,7 @@ setup_fish_widget (FishApplet *fish)
 
 	load_fish_image (fish);
 
-	update_pixmap (fish);
+	update_surface (fish);
 
 	setup_timeout (fish);
 
@@ -1804,12 +1780,10 @@ setup_fish_widget (FishApplet *fish)
 	gtk_widget_show_all (widget);
 }
 
-static const BonoboUIVerb fish_menu_verbs [] = {
-	BONOBO_UI_UNSAFE_VERB ("FishPreferences", display_preferences_dialog),
-	BONOBO_UI_UNSAFE_VERB ("FishHelp",        display_help_dialog),
-	BONOBO_UI_UNSAFE_VERB ("FishAbout",       display_about_dialog),
-
-        BONOBO_UI_VERB_END
+static const GtkActionEntry fish_menu_verbs [] = {
+	{ "FishPreferences", GTK_STOCK_PROPERTIES, N_("_Preferences"),
+	  NULL, NULL,
+	  G_CALLBACK (display_preferences_dialog) }
 };
 
 static void
@@ -1831,8 +1805,11 @@ fish_migrate_to_210 (FishApplet *fish)
 static gboolean
 fish_applet_fill (FishApplet *fish)
 {
-	PanelApplet *applet = (PanelApplet *) fish;
-	GError      *error = NULL;
+	PanelApplet    *applet = (PanelApplet *) fish;
+	GtkActionGroup *action_group;
+	GtkAction      *action;
+	gchar          *ui_path;
+	GError         *error = NULL;
 
 	fish->orientation = panel_applet_get_orient (applet);
 
@@ -1896,20 +1873,22 @@ fish_applet_fill (FishApplet *fish)
 		fish->rotate = FALSE; /* Fallback */
 	}
 
-	panel_applet_setup_menu_from_file (
-		applet, NULL, "GNOME_FishApplet.xml",
-		NULL, fish_menu_verbs, fish);
+	action_group = gtk_action_group_new ("Fish Applet Actions");
+	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (action_group,
+				      fish_menu_verbs,
+				      G_N_ELEMENTS (fish_menu_verbs),
+				      fish);
+	ui_path = g_build_filename (FISH_MENU_UI_DIR, "fish-menu.xml", NULL);
+	panel_applet_setup_menu_from_file (applet, ui_path, action_group);
+	g_free (ui_path);
 
-	if (panel_applet_get_locked_down (applet)) {
-		BonoboUIComponent *popup_component;
+	action = gtk_action_group_get_action (action_group, "FishPreferences");
+	g_object_bind_property (applet, "locked-down",
+				action, "visible",
+				G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
-		popup_component = panel_applet_get_popup_component (applet);
-
-		bonobo_ui_component_set_prop (popup_component,
-					      "/commands/FishPreferences",
-					      "hidden", "1",
-					      NULL);
-	}
+	g_object_unref (action_group);
 
 #ifndef FISH_INPROCESS
 	gtk_window_set_default_icon_name (FISH_ICON);
@@ -1926,14 +1905,14 @@ fishy_factory (PanelApplet *applet,
 {
 	gboolean retval = FALSE;
 
-	if (!strcmp (iid, "OAFIID:GNOME_FishApplet"))
+	if (!strcmp (iid, "FishApplet"))
 		retval = fish_applet_fill (FISH_APPLET (applet));
 
 	return retval;
 }
 
 static void
-fish_applet_destroy (GtkObject *object)
+fish_applet_dispose (GObject *object)
 {
 	FishApplet *fish = (FishApplet *) object;
 	int         i;
@@ -1965,18 +1944,14 @@ fish_applet_destroy (GtkObject *object)
 		g_object_unref (fish->client);
 	fish->client = NULL;
 
-	if (fish->pixmap)
-		g_object_unref (fish->pixmap);
-	fish->pixmap = NULL;
+	if (fish->surface)
+		cairo_surface_destroy (fish->surface);
+	fish->surface = NULL;
 
 	if (fish->pixbuf)
 		g_object_unref (fish->pixbuf);
 	fish->pixbuf = NULL;
 
-	if (fish->about_dialog)
-		gtk_widget_destroy (fish->about_dialog);
-	fish->about_dialog = NULL;
-
 	if (fish->preferences_dialog)
 		gtk_widget_destroy (fish->preferences_dialog);
 	fish->preferences_dialog = NULL;
@@ -1991,7 +1966,7 @@ fish_applet_destroy (GtkObject *object)
 
 	fish_close_channel (fish);
 
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
 static void
@@ -2013,11 +1988,14 @@ fish_applet_instance_init (FishApplet      *fish,
 
 	fish->frame         = NULL;
 	fish->drawing_area  = NULL;
-	fish->pixmap        = NULL;
+	fish->surface       = NULL;
 	fish->timeout       = 0;
 	fish->current_frame = 0;
 	fish->in_applet     = FALSE;
 
+	fish->requisition.width  = -1;
+	fish->requisition.height = -1;
+
 	fish->prev_allocation.x      = -1;
 	fish->prev_allocation.y      = -1;
 	fish->prev_allocation.width  = -1;
@@ -2025,8 +2003,6 @@ fish_applet_instance_init (FishApplet      *fish,
 
 	fish->pixbuf = NULL;
 
-	fish->about_dialog = NULL;
-
 	fish->preferences_dialog = NULL;
 	fish->name_entry         = NULL;
 	fish->command_label      = NULL;
@@ -2061,14 +2037,14 @@ fish_applet_instance_init (FishApplet      *fish,
 static void
 fish_applet_class_init (FishAppletClass *klass)
 {
-	PanelAppletClass *applet_class    = (PanelAppletClass *) klass;
-	GtkObjectClass   *gtkobject_class = (GtkObjectClass *) klass;
+	PanelAppletClass *applet_class  = (PanelAppletClass *) klass;
+	GObjectClass     *gobject_class = (GObjectClass *) klass;
 
 	parent_class = g_type_class_peek_parent (klass);
 
 	applet_class->change_orient = fish_applet_change_orient;
 
-	gtkobject_class->destroy = fish_applet_destroy;
+	gobject_class->dispose = fish_applet_dispose;
 
 	init_fools_day ();
 }
@@ -2098,17 +2074,14 @@ fish_applet_get_type (void)
 }
 
 #ifdef FISH_INPROCESS
-PANEL_APPLET_BONOBO_SHLIB_FACTORY ("OAFIID:GNOME_FishApplet_Factory",
-				   fish_applet_get_type (),
-				   "That-stupid-fish",
-				   fishy_factory,
-				   NULL)
+PANEL_APPLET_IN_PROCESS_FACTORY ("FishAppletFactory",
+				 fish_applet_get_type (),
+				 fishy_factory,
+				 NULL)
 
 #else
-PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_FishApplet_Factory",
-			     fish_applet_get_type (),
-			     "That-stupid-fish",
-			     "0",
-			     fishy_factory,
-			     NULL)
+PANEL_APPLET_OUT_PROCESS_FACTORY ("FishAppletFactory",
+				  fish_applet_get_type (),
+				  fishy_factory,
+				  NULL)
 #endif
