@@ -51,8 +51,6 @@ typedef struct {
 	GtkWidget *move_minimized_radio;
 	GtkWidget *change_workspace_radio;
 
-	GtkWidget *about;
-
 	/* gconf listeners id */
 	guint listeners [3];
 } TasklistData;
@@ -166,9 +164,6 @@ destroy_tasklist(GtkWidget * widget, TasklistData *tasklist)
 	if (tasklist->properties_dialog)
 		gtk_widget_destroy (tasklist->properties_dialog);
 
-	if (tasklist->about)
-		gtk_widget_destroy (tasklist->about);
-
         g_free (tasklist);
 }
 
@@ -439,6 +434,7 @@ window_list_applet_fill (PanelApplet *applet)
 {
 	TasklistData *tasklist;
 	GtkActionGroup *action_group;
+	GtkAction *action;
 	gchar *ui_path;
 	GError *error;
 	GConfValue *value;
@@ -544,12 +540,11 @@ window_list_applet_fill (PanelApplet *applet)
 					   ui_path, action_group);
 	g_free (ui_path);
 
-	if (panel_applet_get_locked_down (PANEL_APPLET (tasklist->applet))) {
-		GtkAction *action;
+	action = gtk_action_group_get_action (action_group, "TasklistPreferences");
+	g_object_bind_property (tasklist->applet, "locked-down",
+				action, "visible",
+				G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
-		action = gtk_action_group_get_action (action_group, "TasklistPreferences");
-		gtk_action_set_visible (action, FALSE);
-	}
 	g_object_unref (action_group);
 
 	gtk_widget_show (tasklist->applet);
