@@ -239,13 +239,31 @@ static void
 panel_action_connect_server (GtkWidget *widget)
 {
 	GdkScreen *screen;
+	GAppInfo  *app_info;
 	GError    *error;
-	
+
 	screen = gtk_widget_get_screen (GTK_WIDGET (widget));
 	error = NULL;
+	app_info = g_app_info_create_from_commandline ("nautilus-connect-server",
+						       _("Connect to server"),
+						       G_APP_INFO_CREATE_NONE,
+						       &error);
 
-	gdk_spawn_command_line_on_screen (screen, "nautilus-connect-server",
-					  &error);
+	if (!error) {
+		GdkAppLaunchContext *launch_context;
+		GdkDisplay          *display;
+
+		display = gdk_screen_get_display (screen);
+		launch_context = gdk_display_get_app_launch_context (display);
+		gdk_app_launch_context_set_screen (launch_context, screen);
+
+		g_app_info_launch (app_info, NULL,
+				   G_APP_LAUNCH_CONTEXT (launch_context),
+				   &error);
+
+		g_object_unref (launch_context);
+		g_object_unref (app_info);
+	}
 
 	if (error) {
 		panel_error_dialog (NULL, screen,
@@ -262,7 +280,6 @@ typedef struct {
 	char                   *icon_name;
 	char                   *text;
 	char                   *tooltip;
-	char                   *help_index;
 	char                   *drag_id;
 	void                  (*invoke)      (GtkWidget         *widget);
 	void                  (*setup_menu)  (PanelActionButton *button);
@@ -276,7 +293,7 @@ typedef struct {
 static PanelAction actions [] = {
 	{
 		PANEL_ACTION_NONE,
-		NULL, NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
 		NULL, NULL, NULL, NULL
 	},
 	{
@@ -284,7 +301,6 @@ static PanelAction actions [] = {
 		PANEL_ICON_LOCKSCREEN,
 		N_("Lock Screen"),
 		N_("Protect your computer from unauthorized use"),
-		"gospanel-21",
 		"ACTION:lock:NEW",
 		panel_action_lock_screen,
 		panel_action_lock_setup_menu,
@@ -299,7 +315,6 @@ static PanelAction actions [] = {
 		 * "1" (msgctxt: "panel:showusername")) */
 		N_("Log Out..."),
 		N_("Log out of this session to log in as a different user"),
-		"gospanel-20",
 		"ACTION:logout:NEW",
 		panel_action_logout, NULL, NULL,
 		panel_lockdown_get_disable_log_out
@@ -309,7 +324,6 @@ static PanelAction actions [] = {
 		PANEL_ICON_RUN,
 		N_("Run Application..."),
 		N_("Run an application by typing a command or choosing from a list"),
-		"gospanel-555",
 		"ACTION:run:NEW",
 		panel_action_run_program, NULL, NULL,
 		panel_lockdown_get_disable_command_line
@@ -319,7 +333,6 @@ static PanelAction actions [] = {
 		PANEL_ICON_SEARCHTOOL,
 		N_("Search for Files..."),
 		N_("Locate documents and folders on this computer by name or content"),
-		"gospanel-554",
 		"ACTION:search:NEW",
 		panel_action_search, NULL, NULL, NULL
 	},
@@ -328,7 +341,6 @@ static PanelAction actions [] = {
 		PANEL_ICON_FORCE_QUIT,
 		N_("Force Quit"),
 		N_("Force a misbehaving application to quit"),
-		"gospanel-563",
 		"ACTION:force-quit:NEW",
 		panel_action_force_quit, NULL, NULL,
 		panel_lockdown_get_disable_force_quit
@@ -338,7 +350,6 @@ static PanelAction actions [] = {
 		PANEL_ICON_REMOTE, //FIXME icon
 		N_("Connect to Server..."),
 		N_("Connect to a remote computer or shared disk"),
-		"nautilus-server-connect",
 		"ACTION:connect-server:NEW",
 		panel_action_connect_server, NULL, NULL, NULL
 	},
@@ -347,7 +358,6 @@ static PanelAction actions [] = {
 		PANEL_ICON_SHUTDOWN,
 		N_("Shut Down..."),
 		N_("Shut down the computer"),
-		"gospanel-20",
 		"ACTION:shutdown:NEW",
 		panel_action_shutdown, NULL, NULL,
 		panel_action_shutdown_reboot_is_disabled
@@ -355,7 +365,7 @@ static PanelAction actions [] = {
 	/* deprecated actions */
 	{
 		PANEL_ACTION_SCREENSHOT,
-		NULL, NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
 		NULL, NULL, NULL, NULL
 	}
 };
@@ -665,7 +675,7 @@ panel_action_button_connect_to_gconf (PanelActionButton *button)
 }
 
 static void
-panel_action_button_style_set (PanelActionButton *button)
+panel_action_button_style_updated (PanelActionButton *button)
 {
 	if (actions [button->priv->type].icon_name != NULL)
 		button_widget_set_icon_name (BUTTON_WIDGET (button), actions [button->priv->type].icon_name);
@@ -704,12 +714,6 @@ panel_action_button_load (PanelActionButtonType  type,
 		return;
 	}
 
-	panel_applet_add_callback (button->priv->info,
-				   "help",
-				   GTK_STOCK_HELP,
-				   _("_Help"),
-				   NULL);
-
 	panel_widget_set_applet_expandable (panel, GTK_WIDGET (button), FALSE, TRUE);
 	panel_widget_set_applet_size_constrained (panel, GTK_WIDGET (button), TRUE);
 
@@ -718,8 +722,8 @@ panel_action_button_load (PanelActionButtonType  type,
 
 	panel_action_button_connect_to_gconf (button);
 
-	g_signal_connect (button, "style-set",
-			  G_CALLBACK (panel_action_button_style_set), NULL);
+	g_signal_connect (button, "style-updated",
+			  G_CALLBACK (panel_action_button_style_updated), NULL);
 }
 
 void
@@ -792,8 +796,8 @@ panel_action_button_load_from_gconf (PanelWidget *panel,
 
 	/* compatibility: migrate from GNOME < 2.13.90 */
 	if (type == PANEL_ACTION_SCREENSHOT)
-		panel_compatiblity_migrate_screenshot_action (panel_gconf_get_client (),
-							      id);
+		panel_compatibility_migrate_screenshot_action (panel_gconf_get_client (),
+							       id);
 	else
 		panel_action_button_load (type, panel, locked,
 					  position, exactpos, id, FALSE);
@@ -808,20 +812,6 @@ panel_action_button_invoke_menu (PanelActionButton *button,
 	g_return_if_fail (button->priv->type > PANEL_ACTION_NONE &&
 			  button->priv->type < PANEL_ACTION_LAST);
 
-	if (!strcmp (callback_name, "help")) {
-		GdkScreen *screen;
-
-		if (!actions [button->priv->type].help_index)
-			return;
-
-		screen = gtk_widget_get_screen (GTK_WIDGET (button));
-
-		panel_show_help (screen, "user-guide",
-				 actions [button->priv->type].help_index, NULL);
-
-		return;
-	}
-
 	if (actions [button->priv->type].invoke_menu)
 		actions [button->priv->type].invoke_menu (button, callback_name);
 }
