@@ -34,6 +34,7 @@
 #include <gdk/gdkx.h>
 
 #include "panel-applets-manager.h"
+#include "panel-bindings.h"
 #include "panel-profile.h"
 #include "panel.h"
 #include "applet.h"
@@ -108,11 +109,16 @@ panel_applet_frame_draw (GtkWidget *widget,
 	gtk_style_context_set_state (context, gtk_widget_get_state_flags (widget));
 
 	cairo_save (cr);
-        gtk_render_handle (context, cr,
-			   frame->priv->handle_rect.x,
-			   frame->priv->handle_rect.y,
-			   frame->priv->handle_rect.width,
-			   frame->priv->handle_rect.height);
+	cairo_rectangle (cr,
+			 frame->priv->handle_rect.x,
+			 frame->priv->handle_rect.y,
+			 frame->priv->handle_rect.width,
+			 frame->priv->handle_rect.height);
+	cairo_clip (cr);
+	gtk_render_handle (context, cr,
+			   0, 0,
+			   gtk_widget_get_allocated_width (widget),
+			   gtk_widget_get_allocated_height (widget));
 	cairo_restore (cr);
 
 	gtk_style_context_restore (context);
@@ -376,14 +382,23 @@ panel_applet_frame_button_changed (GtkWidget      *widget,
 	case 3:
 		if (event->type == GDK_BUTTON_PRESS ||
 		    event->type == GDK_2BUTTON_PRESS) {
+			guint modifiers;
+
+			modifiers = event->state & GDK_MODIFIER_MASK;
+
 			display = gtk_widget_get_display (widget);
 			device_manager = gdk_display_get_device_manager (display);
 			pointer = gdk_device_manager_get_client_pointer (device_manager);
 			gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
 
-			PANEL_APPLET_FRAME_GET_CLASS (frame)->popup_menu (frame,
-									  event->button,
-									  event->time);
+			if (modifiers == panel_bindings_get_mouse_button_modifier_keymask ())
+				PANEL_APPLET_FRAME_GET_CLASS (frame)->popup_edit_menu (frame,
+										       event->button,
+										       event->time);
+			else
+				PANEL_APPLET_FRAME_GET_CLASS (frame)->popup_menu (frame,
+										  event->button,
+										  event->time);
 
 			handled = TRUE;
 		} else if (event->type == GDK_BUTTON_RELEASE)
@@ -821,6 +836,12 @@ panel_applet_frame_activating_free (PanelAppletFrameActivating *frame_act)
 	g_slice_free (PanelAppletFrameActivating, frame_act);
 }
 
+GdkScreen *
+panel_applet_frame_activating_get_screen (PanelAppletFrameActivating *frame_act)
+{
+	return gtk_widget_get_screen (GTK_WIDGET (frame_act->panel));
+}
+
 PanelOrientation
 panel_applet_frame_activating_get_orientation (PanelAppletFrameActivating *frame_act)
 {
