@@ -59,6 +59,10 @@ struct _PanelAppletFrameClass {
 					   guint                button,
 					   guint32              timestamp);
 
+	void     (*popup_edit_menu)       (PanelAppletFrame    *frame,
+					   guint                button,
+					   guint32              timestamp);
+
 	void     (*change_orientation)    (PanelAppletFrame    *frame,
 					   PanelOrientation     orientation);
 
@@ -105,6 +109,7 @@ void  panel_applet_frame_set_panel          (PanelAppletFrame    *frame,
 
 typedef struct _PanelAppletFrameActivating        PanelAppletFrameActivating;
 
+GdkScreen        *panel_applet_frame_activating_get_screen      (PanelAppletFrameActivating *frame_act);
 PanelOrientation  panel_applet_frame_activating_get_orientation (PanelAppletFrameActivating *frame_act);
 guint32           panel_applet_frame_activating_get_size        (PanelAppletFrameActivating *frame_act);
 gboolean          panel_applet_frame_activating_get_locked      (PanelAppletFrameActivating *frame_act);
