@@ -35,8 +35,8 @@
 #include <libpanel-util/panel-xdg.h>
 
 #include "applet.h"
-#include "nothing.h"
 #include "xstuff.h"
+#include "panel-bindings.h"
 #include "panel-config-global.h"
 #include "panel-gconf.h"
 #include "panel-globals.h"
@@ -110,7 +110,7 @@ panel_push_window_busy (GtkWidget *window)
 		if (win != NULL) {
 			GdkCursor *cursor = gdk_cursor_new (GDK_WATCH);
 			gdk_window_set_cursor (win, cursor);
-			gdk_cursor_unref (cursor);
+			g_object_unref (cursor);
 			gdk_flush ();
 		}
 	}
@@ -399,6 +399,9 @@ panel_lock_screen_action (GdkScreen  *screen,
 {
 	GError  *error            = NULL;
 	char    *command          = NULL;
+	GdkAppLaunchContext *launch_context = NULL;
+	GAppInfo            *app_info = NULL;
+	GdkDisplay          *display;
 
 	g_return_if_fail (GDK_IS_SCREEN (screen));
 	g_return_if_fail (action != NULL);
@@ -412,7 +415,22 @@ panel_lock_screen_action (GdkScreen  *screen,
 	if (!command)
 		return;
 
-	if (!gdk_spawn_command_line_on_screen (screen, command, &error)) {
+	app_info = g_app_info_create_from_commandline (command,
+						       NULL,
+						       G_APP_INFO_CREATE_NONE,
+						       &error);
+
+	if (!error) {
+		display = gdk_screen_get_display (screen);
+		launch_context = gdk_display_get_app_launch_context (display);
+		gdk_app_launch_context_set_screen (launch_context, screen);
+		g_app_info_launch (app_info, NULL, G_APP_LAUNCH_CONTEXT (launch_context), &error);
+
+		g_object_unref (launch_context);
+	}
+
+	/* error either by create or launch the command */
+	if (error) {
 		char *primary;
 
 		primary = g_strdup_printf (_("Could not execute '%s'"),
@@ -425,6 +443,7 @@ panel_lock_screen_action (GdkScreen  *screen,
 	}
 
 	g_free (command);
+	g_object_unref (app_info);
 }
 
 void
@@ -1205,3 +1224,77 @@ panel_util_get_file_optional_homedir (const char *location)
 
 	return file;
 }
+
+/*
+ * Keep code in panel-applet-bindings.c in sync!
+ */
+static void
+panel_util_key_event_is_binding (GdkEventKey *event,
+				 GType        type,
+				 const char  *signal_name,
+				 gboolean    *is_popup,
+				 gboolean    *is_popup_modifier)
+{
+	GtkBindingSet   *binding_set;
+	GtkBindingEntry *binding_entry;
+	gboolean         popup = FALSE;
+	gboolean         popup_modifier = FALSE;
+	char            *signal_dash;
+	char            *signal_underscore;
+
+	signal_dash = g_strdup (signal_name);
+	g_strdelimit (signal_dash, "_", '-');
+	signal_underscore = g_strdup (signal_name);
+	g_strdelimit (signal_underscore, "-", '_');
+
+	binding_set = gtk_binding_set_by_class (g_type_class_peek (type));
+
+	for (binding_entry = binding_set->entries;
+	     binding_entry != NULL;
+	     binding_entry = binding_entry->set_next) {
+		GtkBindingSignal *binding_signal;
+
+		for (binding_signal = binding_entry->signals;
+		     binding_signal != NULL;
+		     binding_signal = binding_signal->next) {
+			if (g_strcmp0 (binding_signal->signal_name, signal_dash) == 0 ||
+			    g_strcmp0 (binding_signal->signal_name, signal_underscore) == 0) {
+				if (binding_entry->keyval != event->keyval)
+					break;
+
+				popup = (event->state & GDK_MODIFIER_MASK) == binding_entry->modifiers;
+				popup_modifier = (event->state & GDK_MODIFIER_MASK) == (panel_bindings_get_mouse_button_modifier_keymask ()|binding_entry->modifiers);
+				break;
+			}
+		}
+
+		if (popup || popup_modifier)
+			break;
+	}
+
+	if (is_popup)
+		*is_popup = popup;
+	if (is_popup_modifier)
+		*is_popup_modifier = popup_modifier;
+
+	g_free (signal_dash);
+	g_free (signal_underscore);
+}
+
+void
+panel_util_key_event_is_popup (GdkEventKey *event,
+			       gboolean    *is_popup,
+			       gboolean    *is_popup_modifier)
+{
+	panel_util_key_event_is_binding (event, GTK_TYPE_WIDGET, "popup-menu",
+					 is_popup, is_popup_modifier);
+}
+
+void
+panel_util_key_event_is_popup_panel (GdkEventKey *event,
+				     gboolean    *is_popup,
+				     gboolean    *is_popup_modifier)
+{
+	panel_util_key_event_is_binding (event, PANEL_TYPE_TOPLEVEL, "popup-panel-menu",
+					 is_popup, is_popup_modifier);
+}
